#-------------------------------------------------------------------------------
# Helper macros and variables
#-------------------------------------------------------------------------------
%define _unpackaged_files_terminate_build 0
%define distribution %(/usr/lib/rpm/redhat/dist.sh --distnum)

%if %{?rhel:1}%{!?rhel:0}
    %if %{rhel} >= 7
	%define use_systemd 1
    %else
	%define use_systemd 0
    %endif
%else
    %if %{?fedora}%{!?fedora:0} >= 19
	%define use_systemd 1
    %else
	%define use_systemd 0
    %endif
%endif

# By default we build the eos client SRPMS, if the entire build is required
# then pass the "--with server" flag to the rpmbuild command
%bcond_without server

# Define minimum required dependency for XRootD
%define xrootd_version 4.0.0
%define major_version 4

#-------------------------------------------------------------------------------
# Package definitions
#-------------------------------------------------------------------------------
Summary: The EOS project
Name: eos
Version: 4.1.14
Release: 1%{dist}
Prefix: /usr
License: none
Group: Applications/File

Source: %{name}-%{version}-1.tar.gz
BuildRoot: %{_tmppath}/%{name}-root
%if %{?fedora:1}%{!?fedora:0}
BuildRequires: cmake >= 3.3
%define cmake_cmd cmake
%else
BuildRequires: cmake3 >= 3.3
%define cmake_cmd cmake3
%endif
BuildRequires: xrootd >= %{xrootd_version}
BuildRequires: xrootd-client-devel >= %{xrootd_version}
BuildRequires: xrootd-server-devel >= %{xrootd_version}
BuildRequires: xrootd-private-devel >= %{xrootd_version}
BuildRequires: git, readline-devel
BuildRequires: openssl, openssl-devel
BuildRequires: ncurses, ncurses-devel
BuildRequires: zlib, zlib-devel
BuildRequires: fuse-devel, fuse >= 2.5
BuildRequires: redhat-rpm-config
BuildRequires: protobuf, protobuf-devel, protobuf-compiler
BuildRequires: leveldb-devel
BuildRequires: libattr-devel, xfsprogs-devel

%if %{?_with_server:1}%{!?_with_server:0}
BuildRequires: openldap-devel
BuildRequires: e2fsprogs-devel
BuildRequires: libmicrohttpd, libmicrohttpd-devel >= 0.9.38
BuildRequires: jsoncpp, jsoncpp-devel
%endif

%if 0%{distribution} == 5
BuildRequires: gcc44, gcc44-c++, sparsehash, uuid, uuid-devel,
BuildRequires: zeromq, zeromq-devel, curl-devel, curl
%else
BuildRequires: libuuid-devel, ncurses-static, openssl-static, zlib-static,
BuildRequires: libcurl-devel libcurl, sparsehash-devel
%if 0%{?rhel} == 6 || 0%{?el6} == 1 || (0%{?fedora} >= 18 && 0%{?fedora} <= 21)
BuildRequires: zeromq3, zeromq3-devel
%else
BuildRequires: zeromq, zeromq-devel, cppzmq-devel
%endif
%endif

%if %{use_systemd}
BuildRequires: systemd
Requires:      systemd
%else
Requires: chkconfig
Requires: initscripts
%endif

%description
The EOS software package.

%prep
%setup -n %{name}-%{version}-1

%build
test -e $RPM_BUILD_ROOT && rm -r $RPM_BUILD_ROOT

%if 0%{distribution} == 5
export CC=/usr/bin/gcc44 CXX=/usr/bin/g++44
%endif

mkdir -p build
cd build
%if %{?_with_server:0}%{!?_with_server:1}
%{cmake_cmd} ../ -DRELEASE=1 -DCMAKE_BUILD_TYPE=RelWithDebInfo -DCLIENT=1
%else
%{cmake_cmd} ../ -DRELEASE=1 -DCMAKE_BUILD_TYPE=RelWithDebInfo
%endif
%{__make} %{_smp_mflags}

%install
cd build
%{__make} install DESTDIR=$RPM_BUILD_ROOT
echo "Installed!"

%clean
rm -rf $RPM_BUILD_ROOT

%if %{?_with_server:1}%{!?_with_server:0}
#-------------------------------------------------------------------------------
# Package eos-server
#-------------------------------------------------------------------------------
%package -n eos-server
Summary: The EOS server installation
Group: Applications/File

Requires: xrootd >= %{xrootd_version}
Requires: xrootd-client >= %{xrootd_version}
Requires: eos-client
Requires: libmicrohttpd >= 0.9.38
Requires: acl
Requires: gdb
Requires: protobuf
Requires: jemalloc
Requires: jsoncpp

%if 0%{distribution} == 5
Requires: zeromq
Requires: curl
%else
Requires: libcurl
%if 0%{?rhel} == 6 || 0%{?el6} == 1 || (0%{?fedora} >= 18 && 0%{?fedora} <= 21)
BuildRequires: zeromq3, zeromq3-devel
%else
BuildRequires: zeromq, zeromq-devel, cppzmq-devel
%endif
%endif

%description -n eos-server
The EOS server installation containing MGM, FST & MQ service.

%files -n eos-server
%defattr(-, root, root, -)
%{_bindir}/xrdmqdumper
%{_sbindir}/eosha
%{_sbindir}/eoshapl
%{_sbindir}/eosfilesync
%{_sbindir}/eosdirsync
%{_sbindir}/eos-tty-broadcast
%{_sbindir}/eos-log-compact
%{_sbindir}/eos-log-repair
%{_sbindir}/eossh-timeout
%{_sbindir}/eosfstregister
%{_sbindir}/eosfstinfo
%{_sbindir}/eosadmin
%{_sbindir}/eos-check-blockxs
%{_sbindir}/eos-udp-dumper
%{_sbindir}/eos-compute-blockxs
%{_sbindir}/eos-scan-fs
%{_sbindir}/eos-adler32
%{_sbindir}/eos-mmap
%{_sbindir}/eos-repair-tool
%{_sbindir}/eos-ioping
%{_sbindir}/eos-iobw
%{_sbindir}/eos-iops
%{_libdir}/libeosCommonServer.so.%{version}
%{_libdir}/libeosCommonServer.so.%{major_version}
%{_libdir}/libeosCommonServer.so
%{_libdir}/libEosFstOss.so
%{_libdir}/libXrdEosFst.so
%{_libdir}/libEosPluginManager.so.%{version}
%{_libdir}/libEosPluginManager.so.%{major_version}
%{_libdir}/libEosPluginManager.so
%{_libdir}/libEosNsCommon.so.%{version}
%{_libdir}/libEosNsCommon.so.%{major_version}
%{_libdir}/libEosNsCommon.so
%{_libdir}/libEosNsInMemory.so
%{_libdir}/libEosAuthProto.so.%{version}
%{_libdir}/libEosAuthProto.so.%{major_version}
%{_libdir}/libEosAuthProto.so
%{_libdir}/libXrdEosMgm.so
%{_libdir}/libXrdMqOfs.so
%config(noreplace) %{_sysconfdir}/xrd.cf.fst
%config(noreplace) %{_sysconfdir}/xrd.cf.mgm
%config(noreplace) %{_sysconfdir}/xrd.cf.mq
%config(noreplace) %{_sysconfdir}/xrd.cf.global-mq
%config(noreplace) %{_sysconfdir}/xrd.cf.sync
%config(noreplace) %{_sysconfdir}/xrd.cf.fed
%config(noreplace) %{_sysconfdir}/xrd.cf.prefix
%config(noreplace) %{_sysconfdir}/sysconfig/eos.example
%{_sysconfdir}/rc.d/init.d/eos
%{_sysconfdir}/rc.d/init.d/eosha
%{_sysconfdir}/rc.d/init.d/eossync
%{_sysconfdir}/rc.d/init.d/eosslave
%{_sysconfdir}/cron.d/eos-logs
%{_sysconfdir}/cron.d/eos-reports
%{_sysconfdir}/logrotate.d/eos-logs
%dir %attr(700,daemon,daemon) /var/eos
%dir %attr(700,daemon,daemon) /var/eos/wfe
%dir %attr(700,daemon,daemon) /var/eos/wfe/bash/
%dir %attr(755,daemon,daemon) /var/log/eos
%attr(555,daemon,daemon) /var/eos/html/error.html
%attr(555,daemon,daemon) /var/eos/wfe/bash/shell

%post -n eos-server
/sbin/chkconfig --add eos
/sbin/chkconfig --add eosslave
echo "Starting conditional EOS services"
sleep 2
/sbin/service eos condrestart > /dev/null 2>&1 || :
/sbin/service eosd condrestart > /dev/null 2>&1 || :

%preun -n eos-server
if [ $1 = 0 ]; then
  echo "Stopping EOS services"
  /sbin/service eosha stop > /dev/null 2>&1
  /sbin/service eosd stop > /dev/null 2>&1
  /sbin/service eos stop > /dev/null 2>&1 || :
  /sbin/service eossync stop > /dev/null 2>&1
  /sbin/service eosslave stop > /dev/null 2>&1
  /sbin/chkconfig --del eos
  /sbin/chkconfig --del eosslave
fi
%endif

#-------------------------------------------------------------------------------
# Package eos-client
#-------------------------------------------------------------------------------
%package -n eos-client
Summary: The EOS shell client
Group: Applications/File

Requires: xrootd-client >= %{xrootd_version}
Requires: protobuf

%description -n eos-client
The EOS shell client.

%files -n eos-client
%defattr(-, root, root, -)
%{_bindir}/eos
%{_bindir}/eosdropboxd
%{_bindir}/eoscp
%{_libdir}/libXrdMqClient.so.%{version}
%{_libdir}/libXrdMqClient.so.%{major_version}
%{_libdir}/libXrdMqClient.so
%{_libdir}/libeosCommon.so.%{version}
%{_libdir}/libeosCommon.so.%{major_version}
%{_libdir}/libeosCommon.so

# Documentation
%doc %{_mandir}/man1/

#-------------------------------------------------------------------------------
# Package eos-fuse
#-------------------------------------------------------------------------------
%package -n eos-fuse
Summary: The EOS fuse client with init.d and mount script
Group: Applications/File

Requires: eos-fuse-core
Requires: eos-fuse-sysv

%description -n eos-fuse
The EOS fuse client bundle.

%files -n eos-fuse
%defattr(-, root, root, -)

#-------------------------------------------------------------------------------
# Package eos-fuse-core
#-------------------------------------------------------------------------------
%package -n eos-fuse-core
Summary: The EOS fuse client
Group: Applications/File

Requires: xrootd-client >= %{xrootd_version}
Requires: fuse
Requires: jemalloc

%description -n eos-fuse-core
The EOS fuse core containing eosd and mount scripts.

%files -n eos-fuse-core
%defattr(-, root, root, -)
%{_bindir}/eosd
%{_bindir}/eosfusebind
/sbin/mount.eos
%{_datarootdir}/selinux/targeted/eosfuse.pp
%{_datarootdir}/selinux/mls/eosfuse.pp
%{_datarootdir}/selinux/strict/eosfuse.pp
%{_sysconfdir}/logrotate.d/eos-fuse-logs
%dir %attr(755,daemon,daemon) /var/log/eos
%dir %attr(755,daemon,daemon) /var/log/eos/fuse
%dir %attr(0755, root, root) /var/run/eosd/
%dir %attr(1777, root, root) /var/run/eosd/credentials/
%dir %attr(1777, root, root) /var/run/eosd/credentials/store

# Create the credential store
%if %{?fedora:1}%{!?fedora:0} || 0%{?rhel} >= 7 || 0%{?el7} == 1
%{_usr}/lib/tmpfiles.d/eosd.conf
%endif

%if 0%{distribution} == 5 || 0%{distribution} == 6
%config(noreplace) %{_sysconfdir}/fuse.conf
%{_sysconfdir}/fuse.conf.eos
%else
%{_sysconfdir}/fuse.conf.eos
%endif

%post -n eos-fuse-core
for variant in mls strict targeted
do
  /usr/sbin/semodule -s $variant -i \
  /usr/share/selinux/$variant/eosfuse.pp &> /dev/null || :
done

%preun -n eos-fuse-core
if [ $1 -eq  0 ] ; then
  for variant in mls strict targeted ; do
    /usr/sbin/semodule -s $variant -r eosfuse &> /dev/null || :
  done
fi

%postun -n eos-fuse-core
if [ $1 -eq 0 ]; then
  for variant in mls strict targeted ; do
    /usr/sbin/semodule -u /usr/share/selinux/$variant/eosfuse.pp || :
  done
fi

#-------------------------------------------------------------------------------
# Package eos-fuse-sysv
#-------------------------------------------------------------------------------
%package -n eos-fuse-sysv
Summary: The EOS fuse client
Group: Applications/File

Requires: eos-fuse-core

%description -n eos-fuse-sysv
The EOS fuse SYSV init scripts.

%files -n eos-fuse-sysv
%defattr(-, root, root, -)
%{_sysconfdir}/rc.d/init.d/eosd

%post -n eos-fuse-sysv
%if %{?fedora:1}%{!?fedora:0} || 0%{?rhel} >= 7 || 0%{?el7} == 1
  echo "Skipping chkconfig for eosd"
%else
  /sbin/chkconfig --add eosd
%endif

%preun -n eos-fuse-sysv
%if %{?fedora:1}%{!?fedora:0} || 0%{?rhel} >= 7 || 0%{?el7} == 1
  echo "Skipping chkconfig for eosd"
%else
  if [ $1 = 0 ]; then
    echo "Stopping EOS FUSE services"
    /sbin/service eosd stop > /dev/null 2>&1 || :
    /sbin/chkconfig --del eosd
  fi
%endif

%if %{?_with_server:1}%{!?_with_server:0}
#-------------------------------------------------------------------------------
# Package eos-srm
#-------------------------------------------------------------------------------
%package -n eos-srm
Summary: The EOS srm script package for checksumming and space
Group: Applications/File

Requires: eos-client

%description -n eos-srm
The EOS srm package.

%files -n eos-srm
%defattr(-, root, root, -)
%{_sbindir}/eos-srm-used-bytes
%{_sbindir}/eos-srm-max-bytes
%{_sbindir}/eos-srm-checksum

#-------------------------------------------------------------------------------
# Package eos-testkeytab
#-------------------------------------------------------------------------------
%package -n eos-testkeytab
Summary: The EOS testkeytab package
Group: Applications/File

Requires: eos-server

%description -n eos-testkeytab
Contains an example keytab file.

%files -n eos-testkeytab
%config(noreplace) %attr(-, daemon, daemon) %{_sysconfdir}/eos.keytab

#-------------------------------------------------------------------------------
# Package eos-archive only for >= SLC6
#-------------------------------------------------------------------------------
%if 0%{?rhel} >= 6
%package -n eos-archive
Summary: The EOS archive daemon
Group: Applications/File

Requires: python-daemon python-zmq
Requires: xrootd-python >= %{xrootd_version}

%description -n eos-archive
The EOS archive daemon.

%files -n eos-archive
%defattr(-, root, root, -)
/usr/lib/python*
%{_bindir}/eosarchived.py
%{_bindir}/eosarch_run.py
%{_bindir}/eosarch_reconstruct.py
%config(noreplace) %{_sysconfdir}/sysconfig/eosarchived
%config(noreplace) %{_sysconfdir}/eosarchived.conf
%{_sysconfdir}/rc.d/init.d/eosarchived

%post -n eos-archive
/sbin/chkconfig --add eosarchived
echo "Starting conditional EOS archive services"
sleep 2
/sbin/service eosarchived condrestart > /dev/null 2>&1 || :

%preun -n eos-archive
if [ $1 = 0 ]; then
  echo "Stopping EOS archive services"
  /sbin/service eosarchvied stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del eosarchived
fi
%endif

#-------------------------------------------------------------------------------
# Package eos-test
#-------------------------------------------------------------------------------
%package -n eos-test
Summary: The EOS test package
Group: Applications/File

Requires: eos-server cadaver bc

%description -n eos-test
Contains an instance and fuse test script and some test executables and test archives.

%files -n eos-test
%defattr(-, root, root, -)
%{_sbindir}/eos-instance-test
%{_sbindir}/eos-rain-test
%{_sbindir}/eos-fuse-test
%{_sbindir}/xrdcpabort
%{_sbindir}/xrdcpappend
%{_sbindir}/xrdcpposixcache
%{_sbindir}/xrdcpextend
%{_sbindir}/xrdcpholes
%{_sbindir}/xrdcpbackward
%{_sbindir}/xrdcpdownloadrandom
%{_sbindir}/xrdcprandom
%{_sbindir}/xrdcpshrink
%{_sbindir}/xrdcptruncate
%{_sbindir}/xrdcppartial
%{_sbindir}/xrdstress
%{_sbindir}/xrdstress.exe
%{_sbindir}/eos-io-test
%{_sbindir}/eos-io-tool
%attr(444,daemon,daemon) /var/eos/test/fuse/untar/untar.tgz
%attr(444,daemon,daemon) /var/eos/test/fuse/untar/xrootd.tgz

#-------------------------------------------------------------------------------
# Package eos-cleanup
#-------------------------------------------------------------------------------
%package -n eos-cleanup

Summary: The EOS test package
Group: Applications/File

%description -n eos-cleanup
Contains an clean-up scripts to remove 'left-overs' of an EOS instance for FST/MGM/FUSE etc.

%files -n eos-cleanup
%defattr(-, root, root, -)
%{_sbindir}/eos-uninstall
%{_sbindir}/eos-log-clean
%{_sbindir}/eos-fst-clean
%{_sbindir}/eos-mgm-clean

%if %{?yumrpm:1}%{!?yumrpm:0} == 1
#-------------------------------------------------------------------------------
# Package eos-repo-el6
#-------------------------------------------------------------------------------
%package -n eos-repo-el6

Version: generic
Release: 1
BuildArch: noarch

Summary: The EOS YUM repo configuration for EL6
Group: Applications/File

%description -n eos-repo-el6
Contains a yum configuration file for the production EOS EL6 repo

%files -n eos-repo-el6
%defattr(-, root, root, -)
%{_sysconfdir}/yum.repos.d/eos-el6.repo

#-------------------------------------------------------------------------------
# Package eos-repo-el7
#-------------------------------------------------------------------------------
%package -n eos-repo-el7

Version: generic
Release: 1
BuildArch: noarch

Summary: The EOS YUM repo configuration for EL7
Group: Applications/File

%description -n eos-repo-el7
Contains a yum configuration file for the production EOS EL7 repo

%files -n eos-repo-el7
%defattr(-, root, root, -)
%{_sysconfdir}/yum.repos.d/eos-el7.repo

#-------------------------------------------------------------------------------
# Package eos-repo-el6-dev
#-------------------------------------------------------------------------------
%package -n eos-repo-el6-dev

Version: generic
Release: 1
BuildArch: noarch

Summary: The EOS developement YUM repo configuration for EL6
Group: Applications/File

%description -n eos-repo-el6-dev
Contains a yum configuration file for the development EOS EL6 repo

%files -n eos-repo-el6-dev
%defattr(-, root, root, -)
%{_sysconfdir}/yum.repos.d/eos-el6-dev.repo

#-------------------------------------------------------------------------------
# Package eos-repo-el7-dev
#-------------------------------------------------------------------------------
%package -n eos-repo-el7-dev

Version: generic
Release: 1
BuildArch: noarch

Summary: The EOS development YUM repo configuration for EL7
Group: Applications/File

%description -n eos-repo-el7-dev
Contains a yum configuration file for the development EOS EL7 repo

%files -n eos-repo-el7-dev
%defattr(-, root, root, -)
%{_sysconfdir}/yum.repos.d/eos-el7-dev.repo
%endif
%endif
